@@ -6,8 +6,8 @@
 ;; Homepage: https://github.com/emacscollective/epkg
 ;; Keywords: tools
 
-;; Package-Version: 20260201.1503
-;; Package-Revision: 7758de6c8b6d
+;; Package-Version: 20260217.1917
+;; Package-Revision: f0ae7cd28d03
 ;; Package-Requires: (
 ;;     (emacs  "28.1")
 ;;     (compat "30.1")
@@ -251,14 +251,14 @@ database."
 (defclass epkg-savannah-package (epkg-git-package) () :abstract t)
 
 (defclass epkg-gnu-package (epkg-savannah-package)
-  ((url-format      :initform "https://git.savannah.gnu.org/git/%n.git")
-   (repopage-format :initform "https://git.savannah.gnu.org/cgit/%n.git")
-   (homepage-format :initform "https://savannah.gnu.org/projects/%n")))
+  ((url-format      :initform "https://git.savannah.gnu.org/git/%r.git")
+   (repopage-format :initform "https://git.savannah.gnu.org/cgit/%r.git")
+   (homepage-format :initform "https://savannah.gnu.org/projects/%r")))
 
 (defclass epkg-nongnu-package (epkg-savannah-package)
-  ((url-format      :initform "https://git.savannah.nongnu.org/git/%n.git")
-   (repopage-format :initform "https://git.savannah.nongnu.org/cgit/%n.git")
-   (homepage-format :initform "https://savannah.nongnu.org/projects/%n")))
+  ((url-format      :initform "https://git.savannah.nongnu.org/git/%r.git")
+   (repopage-format :initform "https://git.savannah.nongnu.org/cgit/%r.git")
+   (homepage-format :initform "https://savannah.nongnu.org/projects/%r")))
 
 (defclass epkg-subtree-package (epkg-git-package) ())
 
